import { __assign } from './../../external/tslib/tslib.es6.js';
import React, { useCallback } from 'react';
import classnames from 'classnames';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { Typography } from '@highlight-ui/typography';
import { Icon } from '@highlight-ui/icon';
import { DragIcon } from '@highlight-ui/drag-and-drop';
import styles from './MenuItem.module.scss.js';
import { MenuVariants } from '../types.js';
var statusesIconProps = {
  loading: {
    name: 'spinner-third',
    color: 'icon-highlight',
    spin: true
  },
  valid: {
    name: 'check-circle',
    color: 'icon-success'
  },
  invalid: {
    name: 'exclamation-circle',
    color: 'icon-critical'
  },
  warning: {
    name: 'exclamation-triangle',
    color: 'icon-warning'
  }
};

function MenuItem(_a) {
  var _b;

  var item = _a.item,
      isSelected = _a.isSelected,
      onClick = _a.onClick,
      dragRef = _a.dragRef,
      isOver = _a.isOver,
      canDrop = _a.canDrop,
      variant = _a.variant;
  var statusIconProps = item.status && statusesIconProps[item.status];
  var isAnchor = variant === MenuVariants.ANCHOR;
  var selectedStyle = isAnchor ? styles.isSelectedAnchor : styles.isSelected;
  var onClickHandler = useCallback(function (e) {
    e.stopPropagation();
    onClick(item);
  }, [item, onClick]);
  return /*#__PURE__*/React.createElement("button", __assign({
    type: "button",
    disabled: item.disabled,
    onClick: onClickHandler,
    className: classnames(styles.button, (_b = {}, _b[styles.disabled] = item.disabled, _b[selectedStyle] = isSelected, _b[styles.isOver] = isOver && !isSelected, _b[styles.canDrop] = canDrop && !isSelected, _b[styles.anchorButton] = isAnchor, _b))
  }, parseMetadata(item.metadata)), /*#__PURE__*/React.createElement("div", {
    className: styles.titleContainer
  }, dragRef && /*#__PURE__*/React.createElement(DragIcon, {
    dragRef: dragRef
  }), /*#__PURE__*/React.createElement(Typography, {
    variant: isSelected ? 'button-1' : 'body-1',
    component: "span",
    className: classnames(styles.ellipsis)
  }, item.title)), statusIconProps && /*#__PURE__*/React.createElement(Icon, {
    className: styles.statusIcon,
    name: statusIconProps.name,
    color: statusIconProps.color,
    spin: statusIconProps.spin,
    type: "solid",
    size: 12
  }));
}

export { MenuItem as default };
//# sourceMappingURL=MenuItem.js.map
